@@ -7,6 +7,10 @@
 #  the U.S. Government retains certain rights in this software.
 #  _________________________________________________________________________
 
+import pyutilib.component.core 
+pyutilib.component.core.PluginGlobals.push_env("pyutilib.workflow")
+
+from globals import *
 from connections import *
 from resource import *
 from task import *
@@ -14,3 +18,8 @@ from workflow import *
 from file import *
 from executable import *
 from options import *
+from tasks import *
+
+pyutilib.component.core.PluginGlobals.pop_env()
+
+
