@@ -27,6 +27,7 @@ def _collect_parser_groups(t):
             t._parser_group[key].parser = parser
             parser.add_option_group(t._parser_group[key])
 
+
 class Workflow(object):
 
     def __init__(self):
@@ -53,7 +54,10 @@ class Workflow(object):
                    self.start_task.outputs.declare(name)
                #print "Z",self.start_task.outputs
                #print "Z",self.start_task.outputs[name]
+               # TODO: this is a bit of a hack...
+               val = getattr(task.inputs,name).get_value()
                setattr(task.inputs, name, getattr(self.start_task.outputs, name))
+               getattr(self.start_task.outputs,name).set_value(val)
                #print "Z",task.inputs
                #print "Z",self.start_task.outputs[name].from_task.id
                #print "Z",self.start_task.outputs[name].to_task.id
@@ -71,7 +75,7 @@ class Workflow(object):
     def __call__(self, **kwds):
         for key in kwds:
             if key not in self.start_task.outputs:
-                raise ValueError, "Cannot specify value for option %s.  Valid open names are %s" % (key, self.start_task.outputs.keys())
+                raise ValueError, "Cannot specify value for option %s.  Valid option names are %s" % (key, self.start_task.outputs.keys())
             self.start_task.outputs[key].set_value( kwds[key] )
         self.execute()
         ans = {}
@@ -83,6 +87,9 @@ class Workflow(object):
     def set_options(self, args):
         self._dfs_([self.start_task.id], lambda t: t.set_options(args))
 
+    def options(self):
+        return self.start_task.outputs.keys()
+
     def print_help(self):
         parser = OptionParser()
         self._dfs_([self.start_task.id], _collect_parser_groups)
